==> nomachine-8.4.2-1-x86_64.pkg.tar.zst: NX/lib/perl/nxnode/Common/NXTranslator.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2023 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXNODE, NX protocol compression and NX extensions to this software      #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
package Common::NXTranslator;no warnings;(my (%__translation)=());sub init{(my $language
=shift (@_));if (__isGerman ($language)){main::nxrequire (((
"\x43\x6f\x6d\x6d\x6f\x6e".$GLOBAL::DIRECTORY_SLASH).
"\x4e\x58\x47\x65\x72\x6d\x61\x6e\x4d\x65\x73\x73\x61\x67\x65\x73"));((
%__translation)=Common::NXGermanMessages::getGermanTranslations ());}elsif (
__isSpanish ($language)){main::nxrequire ((("\x43\x6f\x6d\x6d\x6f\x6e".
$GLOBAL::DIRECTORY_SLASH).
"\x4e\x58\x53\x70\x61\x6e\x69\x73\x68\x4d\x65\x73\x73\x61\x67\x65\x73"));((
%__translation)=Common::NXSpanishMessages::getSpanishTranslations ());}elsif (
__isFrench ($language)){main::nxrequire ((("\x43\x6f\x6d\x6d\x6f\x6e".
$GLOBAL::DIRECTORY_SLASH).
"\x4e\x58\x46\x72\x65\x6e\x63\x68\x4d\x65\x73\x73\x61\x67\x65\x73"));((
%__translation)=Common::NXFrenchMessages::getFrenchTranslations ());}elsif (
__isItalian ($language)){main::nxrequire ((("\x43\x6f\x6d\x6d\x6f\x6e".
$GLOBAL::DIRECTORY_SLASH).
"\x4e\x58\x49\x74\x61\x6c\x69\x61\x6e\x4d\x65\x73\x73\x61\x67\x65\x73"));((
%__translation)=Common::NXItalianMessages::getItalianTranslations ());}elsif (
__isPolish ($language)){main::nxrequire ((("\x43\x6f\x6d\x6d\x6f\x6e".
$GLOBAL::DIRECTORY_SLASH).
"\x4e\x58\x50\x6f\x6c\x69\x73\x68\x4d\x65\x73\x73\x61\x67\x65\x73"));((
%__translation)=Common::NXPolishMessages::getPolishTranslations ());}elsif (
__isPortuguese ($language)){main::nxrequire ((("\x43\x6f\x6d\x6d\x6f\x6e".
$GLOBAL::DIRECTORY_SLASH).
"\x4e\x58\x50\x6f\x72\x74\x75\x67\x75\x65\x73\x65\x4d\x65\x73\x73\x61\x67\x65\x73"
));((%__translation)=Common::NXPortugueseMessages::getPortugueseTranslations ())
;}elsif (__isRussian ($language)){main::nxrequire ((("\x43\x6f\x6d\x6d\x6f\x6e".
$GLOBAL::DIRECTORY_SLASH).
"\x4e\x58\x52\x75\x73\x73\x69\x61\x6e\x4d\x65\x73\x73\x61\x67\x65\x73"));((
%__translation)=Common::NXRussianMessages::getRussianTranslations ());}(
$Common::NXTranslator::language=$language);}sub translate{(my $message=shift (@_
));(my $result=shift (@_));(my $translation=$__translation{$message});if ((not (
defined ($translation)))){Logger::debug3 (((
"\x4d\x65\x73\x73\x61\x67\x65\x20\x27".$message).
"\x27\x20\x69\x73\x20\x6e\x6f\x74\x20\x74\x72\x61\x6e\x73\x6c\x61\x74\x65\x64\x2e"
));return ((0x0afb+ 2067-0x130e));}($$result=$translation);Logger::debug3 (((((
"\x54\x72\x61\x6e\x73\x6c\x61\x74\x65\x64\x20\x6d\x65\x73\x73\x61\x67\x65\x20\x27"
.$message)."\x27\x20\x74\x6f\x20\x27").$translation)."\x27\x2e"));return (
(0x0845+ 5086-0x1c22));}sub getLanguage{if (($language ne (""))){return (
$language);}else{return (undef);}}sub __isGerman{(my $language=shift (@_));if ((
$language eq "\x64\x65\x5f\x44\x45")){return ((0x1707+ 2667-0x2171));}return (
(0x0bb6+ 1189-0x105b));}sub __isSpanish{(my $language=shift (@_));if (($language
 eq "\x65\x73\x5f\x45\x53")){return ((0x12fc+ 674-0x159d));}return (
(0x08b5+ 3845-0x17ba));}sub __isFrench{(my $language=shift (@_));if (($language 
eq "\x66\x72\x5f\x46\x52")){return ((0x143c+ 2494-0x1df9));}return (
(0x099d+ 6770-0x240f));}sub __isItalian{(my $language=shift (@_));if (($language
 eq "\x69\x74\x5f\x49\x54")){return ((0x0193+ 5194-0x15dc));}return (
(0x0cb3+ 3433-0x1a1c));}sub __isPolish{(my $language=shift (@_));if (($language 
eq "\x70\x6c\x5f\x50\x4c")){return ((0x04c3+ 447-0x0681));}return (
(0x0eed+ 388-0x1071));}sub __isPortuguese{(my $language=shift (@_));if ((
$language eq "\x70\x74\x5f\x50\x54")){return ((0x164c+ 2128-0x1e9b));}return (
(0x17d0+ 453-0x1995));}sub __isRussian{(my $language=shift (@_));if (($language 
eq "\x72\x75\x5f\x52\x55")){return ((0x0294+ 3591-0x109a));}return (
(0x008c+ 7628-0x1e58));}sub __isEnglish{(my $language=shift (@_));if (($language
 eq "\x65\x6e\x5f\x55\x53")){return ((0x0636+ 1198-0x0ae3));}return (
(0x02f7+ 8234-0x2321));}sub translateTimestampForDateBaseOnLanguage{(my $timestamp
=shift (@_));(my ($sec,$min,$hour,$mday,$mon,$year,$wday,$yday,$isdst)=
Common::NXTime::getLocalTimeFromTimestamp ($timestamp));($year+=
(0x1874+ 3167-0x1d67));(++$mon);my ($date);if (__isEnglish (getLanguage ())){
return (((((((((sprintf ("\x25\x30\x32\x64",$mon)."\x2f").sprintf (
"\x25\x30\x32\x64",$mday))."\x2f").$year)."\x2c\x20").sprintf (
"\x25\x30\x32\x64",$hour))."\x3a").sprintf ("\x25\x30\x32\x64",$min)));}else{
return (((((((((sprintf ("\x25\x30\x32\x64",$mday)."\x2f").sprintf (
"\x25\x30\x32\x64",$mon))."\x2f").$year)."\x2c\x20").sprintf ("\x25\x30\x32\x64"
,$hour))."\x3a").sprintf ("\x25\x30\x32\x64",$min)));}}return (
(0x1812+ 3725-0x269e));

==> nomachine-8.7.1-1-x86_64.pkg.tar.zst: NX/lib/perl/nxnode/Common/NXTranslator.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2023 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXNODE, NX protocol compression and NX extensions to this software      #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
package Common::NXTranslator;no warnings;(my (%__translation)=());sub init{(my $language
=shift (@_));if (__isGerman ($language)){main::nxrequire (((
"\x43\x6f\x6d\x6d\x6f\x6e".$GLOBAL::DIRECTORY_SLASH).
"\x4e\x58\x47\x65\x72\x6d\x61\x6e\x4d\x65\x73\x73\x61\x67\x65\x73"));((
%__translation)=Common::NXGermanMessages::getGermanTranslations ());}elsif (
__isSpanish ($language)){main::nxrequire ((("\x43\x6f\x6d\x6d\x6f\x6e".
$GLOBAL::DIRECTORY_SLASH).
"\x4e\x58\x53\x70\x61\x6e\x69\x73\x68\x4d\x65\x73\x73\x61\x67\x65\x73"));((
%__translation)=Common::NXSpanishMessages::getSpanishTranslations ());}elsif (
__isFrench ($language)){main::nxrequire ((("\x43\x6f\x6d\x6d\x6f\x6e".
$GLOBAL::DIRECTORY_SLASH).
"\x4e\x58\x46\x72\x65\x6e\x63\x68\x4d\x65\x73\x73\x61\x67\x65\x73"));((
%__translation)=Common::NXFrenchMessages::getFrenchTranslations ());}elsif (
__isItalian ($language)){main::nxrequire ((("\x43\x6f\x6d\x6d\x6f\x6e".
$GLOBAL::DIRECTORY_SLASH).
"\x4e\x58\x49\x74\x61\x6c\x69\x61\x6e\x4d\x65\x73\x73\x61\x67\x65\x73"));((
%__translation)=Common::NXItalianMessages::getItalianTranslations ());}elsif (
__isPolish ($language)){main::nxrequire ((("\x43\x6f\x6d\x6d\x6f\x6e".
$GLOBAL::DIRECTORY_SLASH).
"\x4e\x58\x50\x6f\x6c\x69\x73\x68\x4d\x65\x73\x73\x61\x67\x65\x73"));((
%__translation)=Common::NXPolishMessages::getPolishTranslations ());}elsif (
__isPortuguese ($language)){main::nxrequire ((("\x43\x6f\x6d\x6d\x6f\x6e".
$GLOBAL::DIRECTORY_SLASH).
"\x4e\x58\x50\x6f\x72\x74\x75\x67\x75\x65\x73\x65\x4d\x65\x73\x73\x61\x67\x65\x73"
));((%__translation)=Common::NXPortugueseMessages::getPortugueseTranslations ())
;}elsif (__isRussian ($language)){main::nxrequire ((("\x43\x6f\x6d\x6d\x6f\x6e".
$GLOBAL::DIRECTORY_SLASH).
"\x4e\x58\x52\x75\x73\x73\x69\x61\x6e\x4d\x65\x73\x73\x61\x67\x65\x73"));((
%__translation)=Common::NXRussianMessages::getRussianTranslations ());}(
$Common::NXTranslator::language=$language);}sub translate{(my $message=shift (@_
));(my $result=shift (@_));(my $translation=$__translation{$message});if ((not (
defined ($translation)))){Logger::debug3 (((
"\x4d\x65\x73\x73\x61\x67\x65\x20\x27".$message).
"\x27\x20\x69\x73\x20\x6e\x6f\x74\x20\x74\x72\x61\x6e\x73\x6c\x61\x74\x65\x64\x2e"
));return ((0x0343+ 7159-0x1f3a));}($$result=$translation);Logger::debug3 (((((
"\x54\x72\x61\x6e\x73\x6c\x61\x74\x65\x64\x20\x6d\x65\x73\x73\x61\x67\x65\x20\x27"
.$message)."\x27\x20\x74\x6f\x20\x27").$translation)."\x27\x2e"));return (
(0x0d37+ 5535-0x22d5));}sub getLanguage{if (($language ne (""))){return (
$language);}else{return (undef);}}sub __isGerman{(my $language=shift (@_));if ((
$language eq "\x64\x65\x5f\x44\x45")){return ((0x0af3+ 6247-0x2359));}return (
(0x058c+ 4023-0x1543));}sub __isSpanish{(my $language=shift (@_));if (($language
 eq "\x65\x73\x5f\x45\x53")){return ((0x093d+ 5424-0x1e6c));}return (
(0x01e3+ 161-0x0284));}sub __isFrench{(my $language=shift (@_));if (($language 
eq "\x66\x72\x5f\x46\x52")){return ((0x1434+ 2129-0x1c84));}return (
(0x0a52+ 1848-0x118a));}sub __isItalian{(my $language=shift (@_));if (($language
 eq "\x69\x74\x5f\x49\x54")){return ((0x1561+ 1903-0x1ccf));}return (
(0x0488+ 7068-0x2024));}sub __isPolish{(my $language=shift (@_));if (($language 
eq "\x70\x6c\x5f\x50\x4c")){return ((0x18bc+ 3284-0x258f));}return (
(0x1c82+ 1147-0x20fd));}sub __isPortuguese{(my $language=shift (@_));if ((
$language eq "\x70\x74\x5f\x50\x54")){return ((0x1313+ 4147-0x2345));}return (
(0x1724+ 642-0x19a6));}sub __isRussian{(my $language=shift (@_));if (($language 
eq "\x72\x75\x5f\x52\x55")){return ((0x13a7+ 3620-0x21ca));}return (
(0x1106+ 4823-0x23dd));}sub __isEnglish{(my $language=shift (@_));if (($language
 eq "\x65\x6e\x5f\x55\x53")){return ((0x0e35+ 3297-0x1b15));}return (
(0x2132+ 592-0x2382));}sub translateTimestampForDateBaseOnLanguage{(my $timestamp
=shift (@_));(my ($sec,$min,$hour,$mday,$mon,$year,$wday,$yday,$isdst)=
Common::NXTime::getLocalTimeFromTimestamp ($timestamp));($year+=
(0x0bd1+ 1049-0x087e));(++$mon);my ($date);if (__isEnglish (getLanguage ())){
return (((((((((sprintf ("\x25\x30\x32\x64",$mon)."\x2f").sprintf (
"\x25\x30\x32\x64",$mday))."\x2f").$year)."\x2c\x20").sprintf (
"\x25\x30\x32\x64",$hour))."\x3a").sprintf ("\x25\x30\x32\x64",$min)));}else{
return (((((((((sprintf ("\x25\x30\x32\x64",$mday)."\x2f").sprintf (
"\x25\x30\x32\x64",$mon))."\x2f").$year)."\x2c\x20").sprintf ("\x25\x30\x32\x64"
,$hour))."\x3a").sprintf ("\x25\x30\x32\x64",$min)));}}return (
(0x03a8+ 7353-0x2060));
